==> ark-22.07.80.tar.xz: ark-22.07.80/plugins/libarchive/kerfuffle_libarchive_readonly.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract DEB, RPM, ISO, AppImage, XAR and CAB files",
        "Description[ar]": "يفتح ويستخرج ملفات DEB و RPM و ISO و AppImage و XAR و CAB",
        "Description[ast]": "Abre y estrái ficheros deb, rpm, iso, AppImage, XAR y CAB",
        "Description[az]": "DEB, RPM, İSO, Appİmage, XAR, və CAB fayllarını açmaq və çıxartmaq",
        "Description[bg]": "Отваряне и извличане на файлове DEB, RPM, ISO, AppImage, XAR и CAB",
        "Description[ca@valencia]": "Obri i extrau fitxers DEB, RPM, ISO, AppImage, XAR i CAB",
        "Description[ca]": "Obre i extreu fitxers DEB, RPM, ISO, AppImage, XAR i CAB",
        "Description[cs]": "Otevřít a rozbalit soubory DEB, RPM, ISO, AppImage, XAR a CAB",
        "Description[da]": "Åbn og udpak DEB-, RPM-, ISO-, AppImage-, XAR- og CAB-filer",
        "Description[de]": "Öffnen und Entpacken von DEB-, RPM-, ISO-, AppImage-, XAR- und CAB-Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή αρχείων DEB, RPM, ISO, AppImage, XAR και CAB",
        "Description[en_GB]": "Open and extract DEB, RPM, ISO, AppImage, XAR and CAB files",
        "Description[es]": "Abrir y extraer archivos DEB, RPM, ISO, AppImage, XAR y CAB",
        "Description[et]": "DEB-, RPM-, ISO-, AppImage'i, XAR- ja CAB-failide avamine ja lahtipakkimine",
        "Description[eu]": "Ireki eta erauzi DEB, RPM, ISO, AppImage, XAR eta CAB fitxategiak",
        "Description[fi]": "Avaa ja pura Deb-, RPM-, ISO-, AppImage-, Xar- ja Cab-tiedostoja",
        "Description[fr]": "Ouvre et extrait les fichiers DEB, RPM, ISO, AppImage, XAR et CAB",
        "Description[gl]": "Abrir e extraer ficheiros DEB, RPM, ISO, AppImage, XAR e CAB.",
        "Description[hu]": "DEB-, RPM-, ISO-, AppImage-, XAR- és CAB-fájlok megnyitása és kibontása",
        "Description[ia]": "Aperir e Extraher files DEB, RPM, ISO, AppImage, XAR e CAB ",
        "Description[id]": "Buka dan ekstrak file DEB, RPM, ISO, AppImage, XAR dan CAB",
        "Description[it]": "Apri ed estrai file DEB, RPM, ISO, AppImage, XAR e CAB",
        "Description[ja]": "DEB、RPM、ISO、AppImage、XAR、CAB ファイルの閲覧と展開",
        "Description[ko]": "DEB, RPM, ISO, AppImage, XAR, CAB 파일 열고 풀기",
        "Description[nl]": "Open en pak uit DEB, RPM, ISO, AppImage, XAR en CAB bestanden",
        "Description[nn]": "Opna og pakk ut DEB-, RPM-, ISO-, AppImage-, XAR- og CAB-filer",
        "Description[pl]": "Otwiera i wypakowuje pliki DEB, RPM, ISO, AppImage, XAR oraz CAB",
        "Description[pt]": "Abrir e extrair ficheiros DEB, RPM, ISO, AppImage, XAR e CAB",
        "Description[pt_BR]": "Abre e extrai arquivos DEB, RPM, ISO, AppImage, XAR e CAB",
        "Description[ro]": "Deschide și extrage fișiere DEB, RPM, ISO, AppImage, XAR și CAB",
        "Description[ru]": "Открытие и распаковка файлов DEB, RPM, ISO, AppImage, XAR и CAB",
        "Description[sk]": "Otvorenie a extrahovanie súborov DEB, RPM, ISO, AppImage, XAR a CAB",
        "Description[sl]": "Odprite in razširite datoteke DEB, RPM, ISO, AppImage, XAR in CAB",
        "Description[sr@ijekavian]": "Отварање и распакивање ДЕБ, РПМ, ИСО, ап‑имејџ, КСАР и КАБ фајлова",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje DEB, RPM, ISO, AppImage, XAR i CAB fajlova",
        "Description[sr@latin]": "Otvaranje i raspakivanje DEB, RPM, ISO, AppImage, XAR i CAB fajlova",
        "Description[sr]": "Отварање и распакивање ДЕБ, РПМ, ИСО, ап‑имејџ, КСАР и КАБ фајлова",
        "Description[sv]": "Öppna och packa upp DEB-, RPM-, ISO-, AppImage-, XAR- och CAB-filer",
        "Description[tr]": "DEB, RPM, ISO, AppImage, XAR ve CAB dosyalarını açıp çıkarın",
        "Description[uk]": "Здатен відкривати і видобувати дані з архівів DEB, RPM, ISO, AppImage, XAR та CAB",
        "Description[x-test]": "xxOpen and extract DEB, RPM, ISO, AppImage, XAR and CAB filesxx",
        "Description[zh_CN]": "打开和解压 DEB、RPM、ISO、AppImage、XAR 和 CAB 等文件类型",
        "Description[zh_TW]": "開啟並解壓縮 DEB, RPM, ISO, AppImage, XAR 與 CAB 檔案",
        "Id": "kerfuffle_libarchive_readonly",
        "MimeTypes": [
            "@SUPPORTED_READONLY_MIMETYPES@"
        ],
        "Name": "Libarchive plugin (read-only formats)",
        "Name[ar]": "ملحق Libarchive (تنسيقات قراءة فقط)",
        "Name[ast]": "Plugin pa libarchive (formatos de namás llectura)",
        "Name[az]": "Libarchive qoşması (yalnız_oxumaq formatları)",
        "Name[bg]": "Приставка Libarchive (само за четене)",
        "Name[ca@valencia]": "Connector de Libarchive (formats de només lectura)",
        "Name[ca]": "Connector del Libarchive (formats de només lectura)",
        "Name[cs]": "Modul libarchive (formáty pouze pro čtení)",
        "Name[da]": "Libarchive-plugin (skrivebeskyttede formater)",
        "Name[de]": "LibArchive-Modul (Nur lesbare Formate)",
        "Name[el]": "Πρόσθετο Libarchive (ανάγνωση μόνο)",
        "Name[en_GB]": "Libarchive plugin (read-only formats)",
        "Name[es]": "Complemento Libarchive (formatos de solo lectura)",
        "Name[et]": "Libarchive'i plugin (kirjutuskaitstud vormingud)",
        "Name[eu]": "Libarchive plugina (irakurri-soilik formatuak)",
        "Name[fi]": "Libarchive-liitännäinen (vain luku -muodot)",
        "Name[fr]": "Module externe libarchive (formats en lecture seule)",
        "Name[gl]": "Complemento de libarchive (formatos de só lectura)",
        "Name[hu]": "Libarchive bővítmény (csak olvasható formátumok)",
        "Name[ia]": "Libarchive plugin (formatos de sol lectura)",
        "Name[id]": "Plugin Libarchive (format hanya-baca)",
        "Name[it]": "Estensione Libarchive (formati in sola lettura)",
        "Name[ja]": "Libarchive プラグイン(読み込み専用フォーマット)",
        "Name[ko]": "Libarchive 플러그인(읽기 전용 형식)",
        "Name[nl]": "LibArchive-plug-in (alleen-lezen formaten)",
        "Name[nn]": "Libarchive-tillegg (berre lesing)",
        "Name[pl]": "Wtyczka Libarchive (formaty tylko-do-odczytu)",
        "Name[pt]": "'Plugin' da Libarchive (formatos apenas para leitura)",
        "Name[pt_BR]": "Plugin Libarchive (formatos apenas para leitura)",
        "Name[ro]": "Extensie Libarchive (formate numai-citire)",
        "Name[ru]": "Модуль Libarchive (форматы только для чтения)",
        "Name[sk]": "Plugin Libarchive (formáty iba na čítanie)",
        "Name[sl]": "Vstavek Libarchive (samo za branje)",
        "Name[sr@ijekavian]": "Прикључак за Либархив (формати само‑за‑читање)",
        "Name[sr@ijekavianlatin]": "Priključak za libarchive (formati samo‑za‑čitanje)",
        "Name[sr@latin]": "Priključak za libarchive (formati samo‑za‑čitanje)",
        "Name[sr]": "Прикључак за Либархив (формати само‑за‑читање)",
        "Name[sv]": "Libarchive-insticksprogram (endast läsningsformat)",
        "Name[tr]": "Libarchive eklentisi (saltokunur biçimler)",
        "Name[uk]": "Додаток libarchive (формати лише для читання)",
        "Name[x-test]": "xxLibarchive plugin (read-only formats)xx",
        "Name[zh_CN]": "Libarchive 插件 (只读格式)",
        "Name[zh_TW]": "Libarchive 外掛程式（唯讀格式）",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": false,
    "X-KDE-Priority": 100
}

==> ark_22.08.1.orig.tar.xz: ark-22.08.1/plugins/libarchive/kerfuffle_libarchive_readonly.json.cmake <==
{
    "KPlugin": {
        "Description": "Open and extract DEB, RPM, ISO, AppImage, XAR and CAB files",
        "Description[ar]": "يفتح ويستخرج ملفات DEB و RPM و ISO و AppImage و XAR و CAB",
        "Description[ast]": "Abre y estrái ficheros deb, rpm, iso, AppImage, XAR y CAB",
        "Description[az]": "DEB, RPM, İSO, Appİmage, XAR, və CAB fayllarını açmaq və çıxartmaq",
        "Description[bg]": "Отваряне и извличане на файлове DEB, RPM, ISO, AppImage, XAR и CAB",
        "Description[ca@valencia]": "Obri i extrau fitxers DEB, RPM, ISO, AppImage, XAR i CAB",
        "Description[ca]": "Obre i extreu fitxers DEB, RPM, ISO, AppImage, XAR i CAB",
        "Description[cs]": "Otevřít a rozbalit soubory DEB, RPM, ISO, AppImage, XAR a CAB",
        "Description[da]": "Åbn og udpak DEB-, RPM-, ISO-, AppImage-, XAR- og CAB-filer",
        "Description[de]": "Öffnen und Entpacken von DEB-, RPM-, ISO-, AppImage-, XAR- und CAB-Dateien",
        "Description[el]": "Άνοιγμα και εξαγωγή αρχείων DEB, RPM, ISO, AppImage, XAR και CAB",
        "Description[en_GB]": "Open and extract DEB, RPM, ISO, AppImage, XAR and CAB files",
        "Description[es]": "Abrir y extraer archivos DEB, RPM, ISO, AppImage, XAR y CAB",
        "Description[et]": "DEB-, RPM-, ISO-, AppImage'i, XAR- ja CAB-failide avamine ja lahtipakkimine",
        "Description[eu]": "Ireki eta erauzi DEB, RPM, ISO, AppImage, XAR eta CAB fitxategiak",
        "Description[fi]": "Avaa ja pura Deb-, RPM-, ISO-, AppImage-, Xar- ja Cab-tiedostoja",
        "Description[fr]": "Ouvre et extrait les fichiers DEB, RPM, ISO, AppImage, XAR et CAB",
        "Description[gl]": "Abrir e extraer ficheiros DEB, RPM, ISO, AppImage, XAR e CAB.",
        "Description[hu]": "DEB-, RPM-, ISO-, AppImage-, XAR- és CAB-fájlok megnyitása és kibontása",
        "Description[ia]": "Aperir e Extraher files DEB, RPM, ISO, AppImage, XAR e CAB ",
        "Description[id]": "Buka dan ekstrak file DEB, RPM, ISO, AppImage, XAR dan CAB",
        "Description[is]": "Opna og afþjappa DEB, RPM, ISO, AppImage, XAR og CAB-skrár",
        "Description[it]": "Apri ed estrai file DEB, RPM, ISO, AppImage, XAR e CAB",
        "Description[ja]": "DEB、RPM、ISO、AppImage、XAR、CAB ファイルの閲覧と展開",
        "Description[ko]": "DEB, RPM, ISO, AppImage, XAR, CAB 파일 열고 풀기",
        "Description[nl]": "Open en pak uit DEB, RPM, ISO, AppImage, XAR en CAB bestanden",
        "Description[nn]": "Opna og pakk ut DEB-, RPM-, ISO-, AppImage-, XAR- og CAB-filer",
        "Description[pl]": "Otwiera i wypakowuje pliki DEB, RPM, ISO, AppImage, XAR oraz CAB",
        "Description[pt]": "Abrir e extrair ficheiros DEB, RPM, ISO, AppImage, XAR e CAB",
        "Description[pt_BR]": "Abre e extrai arquivos DEB, RPM, ISO, AppImage, XAR e CAB",
        "Description[ro]": "Deschide și extrage fișiere DEB, RPM, ISO, AppImage, XAR și CAB",
        "Description[ru]": "Открытие и распаковка файлов DEB, RPM, ISO, AppImage, XAR и CAB",
        "Description[sk]": "Otvorenie a extrahovanie súborov DEB, RPM, ISO, AppImage, XAR a CAB",
        "Description[sl]": "Odprite in razširite datoteke DEB, RPM, ISO, AppImage, XAR in CAB",
        "Description[sr@ijekavian]": "Отварање и распакивање ДЕБ, РПМ, ИСО, ап‑имејџ, КСАР и КАБ фајлова",
        "Description[sr@ijekavianlatin]": "Otvaranje i raspakivanje DEB, RPM, ISO, AppImage, XAR i CAB fajlova",
        "Description[sr@latin]": "Otvaranje i raspakivanje DEB, RPM, ISO, AppImage, XAR i CAB fajlova",
        "Description[sr]": "Отварање и распакивање ДЕБ, РПМ, ИСО, ап‑имејџ, КСАР и КАБ фајлова",
        "Description[sv]": "Öppna och packa upp DEB-, RPM-, ISO-, AppImage-, XAR- och CAB-filer",
        "Description[tr]": "DEB, RPM, ISO, AppImage, XAR ve CAB dosyalarını açıp çıkarın",
        "Description[uk]": "Здатен відкривати і видобувати дані з архівів DEB, RPM, ISO, AppImage, XAR та CAB",
        "Description[x-test]": "xxOpen and extract DEB, RPM, ISO, AppImage, XAR and CAB filesxx",
        "Description[zh_CN]": "打开和解压 DEB、RPM、ISO、AppImage、XAR 和 CAB 等文件类型",
        "Description[zh_TW]": "開啟並解壓縮 DEB, RPM, ISO, AppImage, XAR 與 CAB 檔案",
        "Id": "kerfuffle_libarchive_readonly",
        "MimeTypes": [
            "@SUPPORTED_READONLY_MIMETYPES@"
        ],
        "Name": "Libarchive plugin (read-only formats)",
        "Name[ar]": "ملحق Libarchive (تنسيقات قراءة فقط)",
        "Name[ast]": "Plugin pa libarchive (formatos de namás llectura)",
        "Name[az]": "Libarchive qoşması (yalnız_oxumaq formatları)",
        "Name[bg]": "Приставка Libarchive (само за четене)",
        "Name[ca@valencia]": "Connector de Libarchive (formats de només lectura)",
        "Name[ca]": "Connector del Libarchive (formats de només lectura)",
        "Name[cs]": "Modul libarchive (formáty pouze pro čtení)",
        "Name[da]": "Libarchive-plugin (skrivebeskyttede formater)",
        "Name[de]": "LibArchive-Modul (Nur lesbare Formate)",
        "Name[el]": "Πρόσθετο Libarchive (ανάγνωση μόνο)",
        "Name[en_GB]": "Libarchive plugin (read-only formats)",
        "Name[es]": "Complemento Libarchive (formatos de solo lectura)",
        "Name[et]": "Libarchive'i plugin (kirjutuskaitstud vormingud)",
        "Name[eu]": "Libarchive plugina (irakurri-soilik formatuak)",
        "Name[fi]": "Libarchive-liitännäinen (vain luku -muodot)",
        "Name[fr]": "Module externe libarchive (formats en lecture seule)",
        "Name[gl]": "Complemento de libarchive (formatos de só lectura)",
        "Name[hu]": "Libarchive bővítmény (csak olvasható formátumok)",
        "Name[ia]": "Libarchive plugin (formatos de sol lectura)",
        "Name[id]": "Plugin Libarchive (format hanya-baca)",
        "Name[is]": "Libarchive-viðbót (skrifvarin snið)",
        "Name[it]": "Estensione Libarchive (formati in sola lettura)",
        "Name[ja]": "Libarchive プラグイン(読み込み専用フォーマット)",
        "Name[ko]": "Libarchive 플러그인(읽기 전용 형식)",
        "Name[nl]": "LibArchive-plug-in (alleen-lezen formaten)",
        "Name[nn]": "Libarchive-tillegg (berre lesing)",
        "Name[pl]": "Wtyczka Libarchive (formaty tylko-do-odczytu)",
        "Name[pt]": "'Plugin' da Libarchive (formatos apenas para leitura)",
        "Name[pt_BR]": "Plugin Libarchive (formatos apenas para leitura)",
        "Name[ro]": "Extensie Libarchive (formate numai-citire)",
        "Name[ru]": "Модуль Libarchive (форматы только для чтения)",
        "Name[sk]": "Plugin Libarchive (formáty iba na čítanie)",
        "Name[sl]": "Vstavek Libarchive (samo za branje)",
        "Name[sr@ijekavian]": "Прикључак за Либархив (формати само‑за‑читање)",
        "Name[sr@ijekavianlatin]": "Priključak za libarchive (formati samo‑za‑čitanje)",
        "Name[sr@latin]": "Priključak za libarchive (formati samo‑za‑čitanje)",
        "Name[sr]": "Прикључак за Либархив (формати само‑за‑читање)",
        "Name[sv]": "Libarchive-insticksprogram (endast läsningsformat)",
        "Name[tr]": "Libarchive eklentisi (saltokunur biçimler)",
        "Name[uk]": "Додаток libarchive (формати лише для читання)",
        "Name[x-test]": "xxLibarchive plugin (read-only formats)xx",
        "Name[zh_CN]": "Libarchive 插件 (只读格式)",
        "Name[zh_TW]": "Libarchive 外掛程式（唯讀格式）",
        "Version": "@RELEASE_SERVICE_VERSION@"
    },
    "X-KDE-Kerfuffle-ReadWrite": false,
    "X-KDE-Priority": 100
}
